Bidi BTD in Select

# Test: dijit/form/Select BIDI

## dijit/form/Select LTR form

#### Setting Defaults

Test AUTO:
Test LTR:
Test RTL:

####

Rich Text (AUTO): Alabama. Alaska. Arizona. חדש. Arkansas. California.
Alabama. Alaska. Arizona. חדש. Arkansas. California.

## dijit/form/Select RTL form

#### Setting Defaults

Test AUTO:
Test LTR:
Test RTL:

####

Rich Text (AUTO): Alabama. Alaska. Arizona. חדש. Arkansas. California.
Alabama. Alaska. Arizona. חדש. Arkansas. California.

#### Widgets created programmatically:

LTR: RTL: AUTO:
validate and close